import { OptionValues as CliOptionValues } from "commander";
import { WorkspaceWithoutExplicitArgs } from "../utils/workspace.js";
import { AdderConfigWithoutExplicitArgs } from "./config.js";
export type BooleanDefaultValue = {
    type: "boolean";
    default: boolean;
};
export type StringDefaultValue = {
    type: "string";
    default: string;
};
export type NumberDefaultValue = {
    type: "number";
    default: number;
};
export type BaseQuestion = {
    question: string;
};
export type BooleanQuestion = BaseQuestion & BooleanDefaultValue;
export type StringQuestion = BaseQuestion & StringDefaultValue;
export type NumberQuestion = BaseQuestion & NumberDefaultValue;
export type Question = BooleanQuestion | StringQuestion | NumberQuestion;
export type OptionDefinition = Record<string, Question>;
export type OptionValues<Args extends OptionDefinition> = {
    [K in keyof Args]: Args[K]["type"] extends "string" ? string : Args[K]["type"] extends "boolean" ? boolean : Args[K]["type"] extends "number" ? number : never;
};
export declare function prepareAndParseCliOptions(config: AdderConfigWithoutExplicitArgs): CliOptionValues;
export declare function askQuestionsAndAssignValuesToWorkspace(config: AdderConfigWithoutExplicitArgs, workspace: WorkspaceWithoutExplicitArgs, cliOptions: CliOptionValues): Promise<void>;
export declare function ensureCorrectOptionTypes(config: AdderConfigWithoutExplicitArgs, workspace: WorkspaceWithoutExplicitArgs): void;
